@@ -12,6 +12,7 @@ from __future__ import annotations
 
 import argparse
 import datetime
+import json
 import os
 import sys
 import traceback
@@ -24,18 +25,6 @@ try:
 except ImportError:
     HAS_ARGCOMPLETE = False
 
-try:
-    import toml
-    HAS_TOML = True
-except ImportError:
-    HAS_TOML = False
-
-try:
-    import tomli
-    HAS_TOMLI = True
-except ImportError:
-    HAS_TOMLI = False
-
 from .ansible import get_ansible_release
 from .changelog_generator import generate_changelog
 from .changes import ChangesBase, add_release, load_changes
@@ -45,6 +34,7 @@ from .fragment import ChangelogFragment, ChangelogFragmentLinter, load_fragments
 from .lint import lint_changelog_yaml
 from .logger import LOGGER, setup_logger
 from .plugins import PluginDescription, load_plugins
+from .toml import has_toml_loader_available, load_toml
 
 
 def set_paths(force: str | None = None,
@@ -87,7 +77,7 @@ def set_paths(force: str | None = None,
         raise ChangelogError(  # pylint: disable=raise-missing-from
             "Only the 'init' command can be used outside an Ansible checkout and outside a "
             "collection repository, or inside one without changelogs/config.yaml.\n"
-            "If you are in a collection without galaxy.yml, specify `--is-collection no` "
+            "If you are in a collection without galaxy.yml, specify `--is-collection yes` "
             "on the command line.")
 
 
@@ -373,7 +363,7 @@ def _get_refresh_config(args: Any,
             elif part == 'fragments-without-archives':
                 refresh_fragments = 'without-archives'
             else:
-                raise Exception(
+                raise ValueError(
                     'The config value always_refresh contains an invalid value "{0}"'.format(
                         part))
     return refresh_plugins, refresh_fragments
@@ -408,7 +398,7 @@ def _do_refresh(args: Any,  # pylint: disable=too-many-arguments
                                    version=changes.latest_version,
                                    force_reload=args.reload_plugins,
                                    use_ansible_doc=args.use_ansible_doc)
-        allow_removals = (refresh_plugins == 'allow-removal')
+        allow_removals = refresh_plugins == 'allow-removal'
 
         changes.update_plugins(plugins, allow_removals=allow_removals)
         changes.update_objects(plugins, allow_removals=allow_removals)
@@ -417,8 +407,8 @@ def _do_refresh(args: Any,  # pylint: disable=too-many-arguments
         if fragments is None:
             fragments = load_fragments(paths, config)
         archive_path_template = config.archive_path_template
-        has_archives = (archive_path_template is not None)
-        with_archives = (refresh_fragments == 'with-archives')
+        has_archives = archive_path_template is not None
+        with_archives = refresh_fragments == 'with-archives'
 
         if config.keep_fragments or (has_archives and with_archives):
             all_fragments = list(fragments)
@@ -441,14 +431,19 @@ def _get_pyproject_toml_version(project_toml_path: str) -> str | None:
     '''
     Try to extract version from pyproject.toml.
     '''
-    if not HAS_TOML and not HAS_TOMLI:
-        raise ChangelogError('Need toml/tomli library to read pyproject.toml')
+    if not has_toml_loader_available():
+        raise ChangelogError('Need tomllib/tomli/toml library to read pyproject.toml')
 
-    with open(project_toml_path, 'r', encoding='utf-8') as f:
-        data = (toml if HAS_TOML else tomli).loads(f.read())
+    data = load_toml(project_toml_path)
+
+    # PEP 621 project metadata (https://peps.python.org/pep-0621/#version)
+    project_data = data.get('project')
+    if isinstance(project_data, dict) and project_data.get('version'):
+        return project_data.get('version')
 
     tool_config = data.get('tool') or {}
 
+    # Python Poetry (https://python-poetry.org/docs/pyproject/#version)
     if 'poetry' in tool_config:
         poetry_config = tool_config['poetry']
         return poetry_config.get('version')
@@ -456,6 +451,16 @@ def _get_pyproject_toml_version(project_toml_path: str) -> str | None:
     return None
 
 
+def _get_package_json_version(package_json_path: str) -> str | None:
+    '''
+    Try to extract version from package.json.
+    '''
+    with open(package_json_path, 'r', encoding='utf-8') as f:
+        data = json.load(f)
+
+    return data.get('version')
+
+
 def _get_project_version(paths: PathsConfig) -> str | None:
     '''
     Try to extract version for other projects.
@@ -464,6 +469,10 @@ def _get_project_version(paths: PathsConfig) -> str | None:
     if os.path.isfile(project_toml_path):
         return _get_pyproject_toml_version(project_toml_path)
 
+    package_json_path = os.path.join(paths.base_dir, 'package.json')
+    if os.path.isfile(package_json_path):
+        return _get_package_json_version(package_json_path)
+
     return None
 
 
@@ -477,6 +486,12 @@ def _get_version_and_codename(paths: PathsConfig, config: ChangelogConfig,
     codename: str | None = args.codename
 
     if not config.is_collection and not config.is_other_project and not (version and codename):
+        if version or codename:
+            # Only one is supplied: error out instead of simply ignoring that one
+            raise ChangelogError(
+                'For ansible-core releases both --version and --codename must be supplied if at'
+                ' least one of them has been supplied'
+            )
         # Both version and codename are required for ansible-core
         try:
             return get_ansible_release()
