@@ -147,7 +147,7 @@ class PathsConfig:
                     return PathsConfig(False, base_dir, None, ansible_doc_bin,
                                        is_other_project=True)
             previous, base_dir = base_dir, os.path.dirname(base_dir)
-            if previous == base_dir:
+            if previous in (base_dir, os.environ.get('__ANTSIBULL_CHANGELOG_CI_ROOT', base_dir)):
                 raise ChangelogError('Cannot identify collection, ansible-core/-base'
                                      ' checkout, or other project.')
 
@@ -211,7 +211,7 @@ class CollectionDetails:
             what_for = 'load field "{0}"'.format(needed_var)
         try:
             galaxy_yaml = load_galaxy_metadata(self.paths)
-        except Exception as exc:  # pylint: disable=broad-except
+        except Exception as exc:
             msg = 'Cannot find galaxy.yml to {0}: {1}'.format(what_for, exc)
             if help_text is not None:
                 msg = '{0}. {1}'.format(msg, help_text)
