@@ -350,7 +350,7 @@ class CollectionCopier:
             new_paths = PathsConfig.force_collection(
                 collection_dir, ansible_doc_bin=self.paths.ansible_doc_path)
             return self.dir, new_paths
-        except Exception:  # pylint: disable=broad-except
+        except Exception:
             shutil.rmtree(self.dir, ignore_errors=True)
             raise
 
@@ -433,7 +433,7 @@ def _get_ansible_core_version(paths: PathsConfig) -> packaging.version.Version:
         match = re.match(regex, output)
         if match:
             return packaging.version.Version(match.group(1))
-    raise Exception(
+    raise RuntimeError(
         f'Cannot extract ansible-core version from ansible-doc --version output:\n{output}')
 
 
